==> 0.9.25.tar.gz: lib/src/form_builder/checkbox_parser.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_neumorphic/flutter_neumorphic.dart';

import 'package:formio_flutter/formio_flutter.dart';
import 'package:formio_flutter/src/abstraction/abstraction.dart';
import 'package:formio_flutter/src/models/models.dart';
import 'package:formio_flutter/src/providers/providers.dart';

/// Extends the abstract class [WidgetParser]
class CheckboxParser extends WidgetParser {
  /// Returns a [Widget] of type [Checkbox]
  @override
  Widget parse(Component map, BuildContext context, ClickListener listener,
      WidgetProvider widgetProvider) {
    return CheckboxCreator(
      map: map,
      widgetProvider: widgetProvider,
    );
  }

  /// [widgetName] => "checkbox"
  @override
  String get widgetName => "checkbox";
}

// ignore: must_be_immutable
class CheckboxCreator extends StatefulWidget implements Manager {
  final Component map;
  bool isSelected;
  final WidgetProvider widgetProvider;
  CheckboxCreator({
    this.map,
    this.widgetProvider,
  });
  @override
  _CheckboxCreatorState createState() => _CheckboxCreatorState();

  /// Returns a [String] with the value contained inside [Component.key]
  @override
  String keyValue() => map.key ?? "checkbox";

  /// Current value of the [Widget]
  @override
  get data => isSelected;
}

class _CheckboxCreatorState extends State<CheckboxCreator> {
  String characters = "";
  final Map<String, dynamic> _mapper = new Map();

  @override
  void initState() {
    super.initState();
    widget.isSelected = (widget.map.defaultValue is bool)
        ? widget.map.defaultValue ?? false
        : false;
    _mapper[widget.map.key] = widget.isSelected;
    Future.delayed(Duration(milliseconds: 10), () {
      widget.widgetProvider.widgetBloc.registerMap(_mapper);
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    bool isVisible = true;
    return (!widget.map.disabled)
        ? StreamBuilder(
            stream: widget.widgetProvider.widgetBloc.widgetsStream,
            builder: (context, AsyncSnapshot<Map<String, dynamic>> snapshot) {
              isVisible = (widget.map.conditional != null &&
                      snapshot.data != null)
                  ? (snapshot.data.containsKey(widget.map.conditional.when) &&
                          snapshot.data[widget.map.conditional.when]
                                  .toString() ==
                              widget.map.conditional.eq)
                      ? widget.map.conditional.show
                      : true
                  : true;
              return (!isVisible)
                  ? Container()
                  : Row(
                      children: [
                        NeumorphicText(
                          (widget.map.label != null) ? widget.map.label : "",
                          textStyle: NeumorphicTextStyle(
                            fontSize: 20.0,
                            fontWeight: FontWeight.w500,
                          ),
                          style: NeumorphicStyle(
                              depth: 13.0,
                              intensity: 0.90,
                              color: Colors.black),
                        ),
                        SizedBox(width: 7.0),
                        NeumorphicCheckbox(
                          value: widget.isSelected,
                          onChanged: (value) {
                            setState(() => widget.isSelected = value);
                            _mapper.update(widget.map.key, (t) => value);
                            widget.widgetProvider.widgetBloc
                                .registerMap(_mapper);
                          },
                        ),
                      ],
                    );
            },
          )
        : Container();
  }
}

==> 0.10.5.tar.gz: lib/src/form_builder/checkbox_parser.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_neumorphic/flutter_neumorphic.dart';

import 'package:formio_flutter/formio_flutter.dart';
import 'package:formio_flutter/src/abstraction/abstraction.dart';
import 'package:formio_flutter/src/models/models.dart';
import 'package:formio_flutter/src/providers/providers.dart';

/// Extends the abstract class [WidgetParser]
class CheckboxParser extends WidgetParser {
  /// Returns a [Widget] of type [Checkbox]
  @override
  Widget parse(Component map, BuildContext context, ClickListener listener,
      WidgetProvider widgetProvider) {
    return CheckboxCreator(
      map: map,
      widgetProvider: widgetProvider,
    );
  }

  /// [widgetName] => "checkbox"
  @override
  String get widgetName => 'checkbox';
}

// ignore: must_be_immutable
class CheckboxCreator extends StatefulWidget implements Manager {
  final Component map;
  bool isSelected;
  final WidgetProvider widgetProvider;
  CheckboxCreator({
    this.map,
    this.widgetProvider,
  });
  @override
  _CheckboxCreatorState createState() => _CheckboxCreatorState();

  /// Returns a [String] with the value contained inside [Component.key]
  @override
  String get keyValue => map.key ?? 'checkbox';

  /// Current value of the [Widget]
  @override
  bool get data => isSelected;
}

class _CheckboxCreatorState extends State<CheckboxCreator> {
  String characters = '';
  final Map<String, dynamic> _mapper = {};

  @override
  void initState() {
    super.initState();
    widget.isSelected = (widget.map.defaultValue is bool)
        ? widget.map.defaultValue ?? false
        : false;

    _mapper[widget.map.key] = widget.isSelected;

    WidgetsBinding.instance.addPostFrameCallback((_) {
      widget.widgetProvider.widgetBloc.registerMap(_mapper);
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    bool isVisible = true;
    return (!widget.map.disabled)
        ? StreamBuilder(
            stream: widget.widgetProvider.widgetBloc.widgetsStream,
            builder: (context, AsyncSnapshot<Map<String, dynamic>> snapshot) {
              isVisible = (widget.map.conditional != null &&
                      snapshot.data != null)
                  ? (snapshot.data.containsKey(widget.map.conditional.when) &&
                          snapshot.data[widget.map.conditional.when]
                                  .toString() ==
                              widget.map.conditional.eq)
                      ? widget.map.conditional.show
                      : !widget.map.conditional.show
                  : true;
              return (!isVisible)
                  ? SizedBox.shrink()
                  : Row(
                      children: [
                        NeumorphicText(
                          (widget.map.label != null) ? widget.map.label : "",
                          textStyle: NeumorphicTextStyle(
                            fontSize: 20.0,
                            fontWeight: FontWeight.w500,
                          ),
                          style: NeumorphicStyle(
                              depth: 13.0,
                              intensity: 0.90,
                              color: Colors.black),
                        ),
                        SizedBox(width: 7.0),
                        NeumorphicCheckbox(
                          value: widget.isSelected,
                          onChanged: (value) {
                            setState(() => widget.isSelected = value);
                            _mapper.update(widget.map.key, (t) => value);
                            widget.widgetProvider.widgetBloc
                                .registerMap(_mapper);
                          },
                        ),
                      ],
                    );
            },
          )
        : Container();
  }
}
